@@ -1,13 +1,12 @@
 #! /usr/bin/env python
-# Python Serial Port Extension for Win32, Linux, BSD, Jython
-# see __init__.py
 #
-# (C) 2001-2008 Chris Liechti <cliechti@gmx.net>
-# this is distributed under a free software license, see license.txt
-
+# This file is part of pySerial - Cross platform serial port support for Python
+# (C) 2001-2015 Chris Liechti <cliechti@gmx.net>
+#
+# SPDX-License-Identifier:    BSD-3-Clause
 """\
 Some tests for the serial module.
-Part of pyserial (http://pyserial.sf.net)  (C)2001-2009 cliechti@gmx.net
+Part of pyserial (http://pyserial.sf.net)  (C)2001-2015 cliechti@gmx.net
 
 Intended to be run on different platforms, to ensure portability of
 the code.
@@ -29,15 +28,10 @@ import sys
 import serial
 
 # on which port should the tests be performed:
-PORT = 0
+PORT = 'loop://'
 
-if sys.version_info >= (3, 0):
-    def data(string):
-        return bytes(string, 'latin1')
-    bytes_0to255 = bytes(range(256))
-else:
-    def data(string): return string
-    bytes_0to255 = ''.join([chr(x) for x in range(256)])
+# indirection via bytearray b/c bytes(range(256)) does something else in Pyhton 2.7
+bytes_0to255 = bytes(bytearray(range(256)))
 
 
 def segments(data, size=16):
@@ -62,7 +56,7 @@ class Test4_Nonblocking(unittest.TestCase):
 
     def test1_ReadEmpty(self):
         """timeout: After port open, the input buffer must be empty"""
-        self.failUnlessEqual(self.s.read(1), data(''), "expected empty buffer")
+        self.assertEqual(self.s.read(1), b'', "expected empty buffer")
 
     def test2_Loopback(self):
         """timeout: each sent character should return (binary test).
@@ -72,18 +66,18 @@ class Test4_Nonblocking(unittest.TestCase):
             self.s.write(block)
             # there might be a small delay until the character is ready (especially on win32)
             time.sleep(0.05)
-            self.failUnlessEqual(self.s.inWaiting(), length, "expected exactly %d character for inWainting()" % length)
-            self.failUnlessEqual(self.s.read(length), block)#, "expected a %r which was written before" % block)
-        self.failUnlessEqual(self.s.read(1), data(''), "expected empty buffer after all sent chars are read")
+            self.assertEqual(self.s.in_waiting, length, "expected exactly %d character for inWainting()" % length)
+            self.assertEqual(self.s.read(length), block)#, "expected a %r which was written before" % block)
+        self.assertEqual(self.s.read(1), b'', "expected empty buffer after all sent chars are read")
 
     def test2_LoopbackTimeout(self):
         """timeout: test the timeout/immediate return.
         partial results should be returned."""
-        self.s.write(data("HELLO"))
+        self.s.write(b"HELLO")
         time.sleep(0.1)    # there might be a small delay until the character is ready (especially on win32 and rfc2217)
         # read more characters as are available to run in the timeout
-        self.failUnlessEqual(self.s.read(10), data('HELLO'), "expected the 'HELLO' which was written before")
-        self.failUnlessEqual(self.s.read(1), data(''), "expected empty buffer after all sent chars are read")
+        self.assertEqual(self.s.read(10), b'HELLO', "expected the 'HELLO' which was written before")
+        self.assertEqual(self.s.read(1), b'', "expected empty buffer after all sent chars are read")
 
 
 class Test3_Timeout(Test4_Nonblocking):
@@ -109,7 +103,7 @@ class SendEvent(threading.Thread):
         time.sleep(self.delay)
         self.x.set()
         if not self.stopped:
-            self.serial.write(data("E"))
+            self.serial.write(b"E")
             self.serial.flush()
 
     def isSet(self):
@@ -135,7 +129,7 @@ class Test1_Forever(unittest.TestCase):
         """no timeout: after port open, the input buffer must be empty (read).
         a character is sent after some time to terminate the test (SendEvent)."""
         c = self.s.read(1)
-        if not (self.event.isSet() and c == data('E')):
+        if not (self.event.isSet() and c == b'E'):
             self.fail("expected marker (evt=%r, c=%r)" % (self.event.isSet(), c))
 
 
@@ -148,8 +142,8 @@ class Test2_Forever(unittest.TestCase):
         self.s.close()
 
     def test1_inWaitingEmpty(self):
-        """no timeout: after port open, the input buffer must be empty (inWaiting)"""
-        self.failUnlessEqual(self.s.inWaiting(), 0, "expected empty buffer")
+        """no timeout: after port open, the input buffer must be empty (in_waiting)"""
+        self.assertEqual(self.s.in_waiting, 0, "expected empty buffer")
 
     def test2_Loopback(self):
         """no timeout: each sent character should return (binary test).
@@ -159,9 +153,9 @@ class Test2_Forever(unittest.TestCase):
             self.s.write(block)
             # there might be a small delay until the character is ready (especially on win32 and rfc2217)
             time.sleep(0.05)
-            self.failUnlessEqual(self.s.inWaiting(), length)#, "expected exactly %d character for inWainting()" % length)
-            self.failUnlessEqual(self.s.read(length), block) #, "expected %r which was written before" % block)
-        self.failUnlessEqual(self.s.inWaiting(), 0, "expected empty buffer after all sent chars are read")
+            self.assertEqual(self.s.in_waiting, length)#, "expected exactly %d character for inWainting()" % length)
+            self.assertEqual(self.s.read(length), block) #, "expected %r which was written before" % block)
+        self.assertEqual(self.s.in_waiting, 0, "expected empty buffer after all sent chars are read")
 
 
 class Test0_DataWires(unittest.TestCase):
@@ -174,25 +168,25 @@ class Test0_DataWires(unittest.TestCase):
 
     def test1_RTS(self):
         """Test RTS/CTS"""
-        self.s.setRTS(0)
+        self.s.rts = False
         time.sleep(1.1)
-        self.failUnless(not self.s.getCTS(), "CTS -> 0")
-        self.s.setRTS(1)
+        self.assertTrue(not self.s.cts, "CTS -> 0")
+        self.s.rts = True
         time.sleep(1.1)
-        self.failUnless(self.s.getCTS(), "CTS -> 1")
+        self.assertTrue(self.s.cts, "CTS -> 1")
 
     def test2_DTR(self):
         """Test DTR/DSR"""
-        self.s.setDTR(0)
+        self.s.dtr = False
         time.sleep(1.1)
-        self.failUnless(not self.s.getDSR(), "DSR -> 0")
-        self.s.setDTR(1)
+        self.assertTrue(not self.s.dsr, "DSR -> 0")
+        self.s.dtr = True
         time.sleep(1.1)
-        self.failUnless(self.s.getDSR(), "DSR -> 1")
+        self.assertTrue(self.s.dsr, "DSR -> 1")
 
     def test3_RI(self):
         """Test RI"""
-        self.failUnless(not self.s.getRI(), "RI -> 0")
+        self.assertTrue(not self.s.ri, "RI -> 0")
 
 
 class Test_MoreTimeouts(unittest.TestCase):
@@ -202,21 +196,28 @@ class Test_MoreTimeouts(unittest.TestCase):
         self.s = serial.serial_for_url(PORT, do_not_open=True)
 
     def tearDown(self):
+        #~ self.s.write(serial.XON)
+        self.s.close()
+        # reopen... some faulty USB-serial adapter make next test fail otherwise...
+        self.s.timeout = 1
+        self.s.xonxoff = False
+        self.s.open()
+        self.s.read(10)
         self.s.close()
 
     def test_WriteTimeout(self):
         """Test write() timeout."""
         # use xonxoff setting and the loop-back adapter to switch traffic on hold
         self.s.port = PORT
-        self.s.writeTimeout = 1
-        self.s.xonxoff = 1
+        self.s.writeTimeout = True
+        self.s.xonxoff = True
         self.s.open()
         self.s.write(serial.XOFF)
         time.sleep(0.5) # some systems need a little delay so that they can react on XOFF
         t1 = time.time()
-        self.failUnlessRaises(serial.SerialTimeoutException, self.s.write, data("timeout please"*200))
+        self.assertRaises(serial.SerialTimeoutException, self.s.write, b"timeout please"*200)
         t2 = time.time()
-        self.failUnless( 0.9 <= (t2-t1) < 2.1, "Timeout not in the given interval (%s)" % (t2-t1))
+        self.assertTrue( 0.9 <= (t2-t1) < 2.1, "Timeout not in the given interval (%s)" % (t2-t1))
 
 
 if __name__ == '__main__':
