@@ -1,10 +1,9 @@
 #!/usr/bin/env python
-#Python Serial Port Extension for Win32, Linux, BSD, Jython
-#see __init__.py
 #
-#(C) 2001-2003 Chris Liechti <cliechti@gmx.net>
-# this is distributed under a free software license, see license.txt
-
+# This file is part of pySerial - Cross platform serial port support for Python
+# (C) 2001-2015 Chris Liechti <cliechti@gmx.net>
+#
+# SPDX-License-Identifier:    BSD-3-Clause
 """Some tests for the serial module.
 Part of pyserial (http://pyserial.sf.net)  (C)2002-2003 cliechti@gmx.net
 
@@ -53,8 +52,8 @@ class TestHighLoad(unittest.TestCase):
         for i in range(self.N):
             q = bytes_0to255
             self.s.write(q)
-            self.failUnlessEqual(self.s.read(len(q)), q) # expected same which was written before
-        self.failUnlessEqual(self.s.inWaiting(), 0) # expected empty buffer after all sent chars are read
+            self.assertEqual(self.s.read(len(q)), q) # expected same which was written before
+        self.assertEqual(self.s.inWaiting(), 0) # expected empty buffer after all sent chars are read
 
     def test1_WriteWriteReadLoopback(self):
         """Send big strings, multiple write one read."""
@@ -62,8 +61,8 @@ class TestHighLoad(unittest.TestCase):
         for i in range(self.N):
             self.s.write(q)
         read = self.s.read(len(q)*self.N)
-        self.failUnlessEqual(read, q*self.N, "expected what was written before. got %d bytes, expected %d" % (len(read), self.N*len(q)))
-        self.failUnlessEqual(self.s.inWaiting(), 0) # "expected empty buffer after all sent chars are read")
+        self.assertEqual(read, q*self.N, "expected what was written before. got %d bytes, expected %d" % (len(read), self.N*len(q)))
+        self.assertEqual(self.s.inWaiting(), 0) # "expected empty buffer after all sent chars are read")
 
 
 if __name__ == '__main__':
