@@ -1,11 +1,9 @@
 #! /usr/bin/env python
 #
-# Python Serial Port Extension for Win32, Linux, BSD, Jython
-# see __init__.py
+# This file is part of pySerial - Cross platform serial port support for Python
+# (C) 2001-2015 Chris Liechti <cliechti@gmx.net>
 #
-# (C) 2001-2009 Chris Liechti <cliechti@gmx.net>
-# this is distributed under a free software license, see license.txt
-
+# SPDX-License-Identifier:    BSD-3-Clause
 """\
 Some tests for the serial module.
 Part of pyserial (http://pyserial.sf.net)  (C)2001-2009 cliechti@gmx.net
@@ -63,10 +61,10 @@ class Test_SerialAndIO(unittest.TestCase):
         self.s.close()
 
     def test_hello_raw(self):
-        self.io.write(unicode("hello\n"))
+        self.io.write(b"hello\n".decode('utf-8'))
         self.io.flush() # it is buffering. required to get the data out
         hello = self.io.readline()
-        self.failUnlessEqual(hello, unicode("hello\n"))
+        self.assertEqual(hello, b"hello\n".decode('utf-8'))
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 if __name__ == '__main__':
