@@ -1,10 +1,9 @@
 #! /usr/bin/env python
-# Python Serial Port Extension for Win32, Linux, BSD, Jython
-# see __init__.py
 #
-# (C) 2010 Chris Liechti <cliechti@gmx.net>
-# this is distributed under a free software license, see license.txt
-
+# This file is part of pySerial - Cross platform serial port support for Python
+# (C) 2010-2015 Chris Liechti <cliechti@gmx.net>
+#
+# SPDX-License-Identifier:    BSD-3-Clause
 """\
 Some tests for the serial module.
 Part of pyserial (http://pyserial.sf.net)  (C)2010 cliechti@gmx.net
@@ -53,16 +52,16 @@ class Test_Readline(unittest.TestCase):
     def test_readline(self):
         """Test readline method"""
         self.s.write(serial.to_bytes([0x31, 0x0a, 0x32, 0x0a, 0x33, 0x0a]))
-        self.failUnlessEqual(self.s.readline(), serial.to_bytes([0x31, 0x0a]))
-        self.failUnlessEqual(self.s.readline(), serial.to_bytes([0x32, 0x0a]))
-        self.failUnlessEqual(self.s.readline(), serial.to_bytes([0x33, 0x0a]))
+        self.assertEqual(self.s.readline(), serial.to_bytes([0x31, 0x0a]))
+        self.assertEqual(self.s.readline(), serial.to_bytes([0x32, 0x0a]))
+        self.assertEqual(self.s.readline(), serial.to_bytes([0x33, 0x0a]))
         # this time we will get a timeout
-        self.failUnlessEqual(self.s.readline(), serial.to_bytes([]))
+        self.assertEqual(self.s.readline(), serial.to_bytes([]))
 
     def test_readlines(self):
         """Test readlines method"""
         self.s.write(serial.to_bytes([0x31, 0x0a, 0x32, 0x0a, 0x33, 0x0a]))
-        self.failUnlessEqual(
+        self.assertEqual(
                 self.s.readlines(),
                 [serial.to_bytes([0x31, 0x0a]), serial.to_bytes([0x32, 0x0a]), serial.to_bytes([0x33, 0x0a])]
                 )
@@ -71,7 +70,7 @@ class Test_Readline(unittest.TestCase):
         """Test xreadlines method (skipped for io based systems)"""
         if hasattr(self.s, 'xreadlines'):
             self.s.write(serial.to_bytes([0x31, 0x0a, 0x32, 0x0a, 0x33, 0x0a]))
-            self.failUnlessEqual(
+            self.assertEqual(
                     list(self.s.xreadlines()),
                     [serial.to_bytes([0x31, 0x0a]), serial.to_bytes([0x32, 0x0a]), serial.to_bytes([0x33, 0x0a])]
                     )
@@ -82,7 +81,7 @@ class Test_Readline(unittest.TestCase):
         lines = []
         for line in self.s:
             lines.append(line)
-        self.failUnlessEqual(
+        self.assertEqual(
                 lines,
                 [serial.to_bytes([0x31, 0x0a]), serial.to_bytes([0x32, 0x0a]), serial.to_bytes([0x33, 0x0a])]
                 )
@@ -91,7 +90,7 @@ class Test_Readline(unittest.TestCase):
         """Test readline with alternative eol settings (skipped for io based systems)"""
         if hasattr(self.s, 'xreadlines'): # test if it is our FileLike base class
             self.s.write(serial.to_bytes("no\rno\nyes\r\n"))
-            self.failUnlessEqual(
+            self.assertEqual(
                     self.s.readline(eol=serial.to_bytes("\r\n")),
                     serial.to_bytes("no\rno\nyes\r\n"))
 
